@@ -1,4 +1,4 @@
-        
+
 
 
 
@@ -11,10 +11,11 @@ doyamlsetup = function() {
     fun = function() {
         if(!is.null(yamlval) && !initial && !stale)
             return(yamlval)
-        
+
         con = url("http://bioconductor.org/config.yaml")
         on.exit(close(con))
-        yaml = inet_handlers(readLines(con))
+        yaml = tryCatch(readLines(con), error=function(e) NULL,
+                        warning = function(w) invokeRestart("muffleWarning"))
         if(is(yaml, "error")) {
             return(NULL)
         } else {
@@ -38,14 +39,22 @@ doyamlsetup = function() {
 ## in zzz.R as delayed assign now.
 ##getBiocYaml = doyamlsetup()
 
+trim_potential_bioc_repos = function(bioc_repos) {
+    if(length(bioc_repos) == 0)
+        return(bioc_repos)
+    keep = sapply(bioc_repos, function(repo) {
+        exst <- inet_handlers(url.exists(repo))
+        is(exst, "error") || isTRUE(exst)
+    })
+
+    bioc_repos[keep]
+}
+
 getBiocReposFromRVers = function() {
     myyaml = getBiocYaml()
     biocvers = getBiocvrFromRvr(myyaml)
     reps = gsub("%%%%", biocvers, biocrepostmpl)
-    exst = inet_handlers(url.exists(reps[4]))
-    if(!is(exst, "error") && !exst) ## extra repo isn't on newer repos
-        reps = reps[-4]
-    reps
+    trim_potential_bioc_repos(reps)
 }
 
 getMultilineYamlField = function(yaml = getBiocYaml(), field) {
@@ -60,21 +69,21 @@ getMultilineYamlField = function(yaml = getBiocYaml(), field) {
     mylines = cleanem(mylines)
     mylines
 }
-    
+
 
 getBiocvrFromRvr = function(yaml  = getBiocYaml(), Rvers, first = TRUE) {
     if(missing(Rvers))
         Rvers = paste(R.version$major, gsub("(.*)\\..*", "\\1", R.version$minor), sep=".")
     if(is.null(yaml))
         return(NULL)
-    
+
     mylines = getMultilineYamlField(yaml, "r_ver_for_bioc_ver")
     mymatty = do.call(rbind, strsplit(mylines, ":"))
     matches = which(mymatty[,2] == Rvers)
     if(all(is.na(matches))) {
         return(getBiocDevelVr())
     }
-    
+
     if(first)
         row = min(matches)
     else
@@ -197,6 +206,8 @@ decrBiocRepo = function(repos, vers = biocVersFromRepo(repos)) {
 biocVersFromRepo = function(repos) gsub(".*/([0-9][^/]*)/.*", "\\1", repos[1])
 
 biocReposFromVers = function(vers = develVers) {
+    if(length(vers) == 0)
+        return(character())
     if(beforeBiocInstaller()) {
         if(!exists("biocinstallRepos")) {
             res =try(source("http://bioconductor.org/biocLite.R"))
@@ -208,7 +219,7 @@ biocReposFromVers = function(vers = develVers) {
         repos = biocinstallRepos()
         repos = repos[grepl("bioconductor.org", repos)]
     } else {
-        
+
         repos = biocBaseRepos()
         repos = repos[grep("BioC", names(repos))]
     }
@@ -216,7 +227,7 @@ biocReposFromVers = function(vers = develVers) {
     bef= gsub("(.*/)[0-9][^/]*/.*", "\\1", repos)
     af = gsub(".*/[0-9][^/]*(/.*)", "\\1", repos)
     paste0(bef, vers, af)
-}    
+}
 
 getRemoteBranches = function(dir = ".") {
 
@@ -224,7 +235,7 @@ getRemoteBranches = function(dir = ".") {
     res = res[!grepl("HEAD ->", res)]
     res = gsub(".*origin/(.*)", "\\1", res)
     res
-}    
+}
 
 
 
@@ -232,39 +243,45 @@ sneakyreqpkg = function(pkg, quietly = FALSE) {
     req = tryCatch(get("requireNamespace"), error = identity)
     if(is(req, "error"))
         req = get("require")
-    
+
     req(pkg, quietly = quietly)
 }
 
-    
 
-getBiocRepos = function() {
-    ## this sucks but I can't afford the dependency on 3.5.x+ that comes
+
+getBiocRepos = function(trim = FALSE) {
+        ## this sucks but I can't afford the dependency on 3.5.x+ that comes
     ## with BiocManager :(
-    if(sneakyreqpkg("BiocManager", quietly = TRUE)) { 
-        bioc = inet_handlers(get("repositories", asNamespace("BiocManager"))())
-    } else if(sneakyreqpkg("BiocInstaller", quietly = TRUE)) {
-        bcrepofun = get("biocinstallRepos", envir = asNamespace("BiocInstaller")) 
-        bioc = bcrepofun()
-    } else if(beforeBiocInstaller()) {
-        if(!exists("biocinstallRepos"))
-            source("http://bioconductor.org/biocLite.R")
-        bioc = biocinstallRepos()
-    } else {
-        if(is.null(defaultBiocRepos)) {
-            bioc = tryCatch(getBiocReposFromRVers(), function(e) character())
-            if(length(bioc) == 0)
-                warning("Unable to determine Bioc repositories. They will not be included in the set of default dependency repos")
-        } else
-            bioc = defaultBiocRepos
-    }
-    if(is(bioc, "error")) 
-        return(character())
+    suppressMessages({
+        if(exists("requireNamespace") && requireNamespace("BiocManager", quietly = TRUE)) {
+            bioc = tryCatch(BiocManager::repositories(),
+                            error = function(e) e,
+                            warning = function(w) NULL)
+        } else if(sneakyreqpkg("BiocInstaller", quietly = TRUE)) {
+            bcrepofun = get("biocinstallRepos", envir = asNamespace("BiocInstaller"))
+            bioc = inet_handlers(suppressWarnings(bcrepofun()))
+        } else if(beforeBiocInstaller()) {
+            if(!exists("biocinstallRepos"))
+                inet_handlers(source("http://bioconductor.org/biocLite.R"))
+            bioc = biocinstallRepos()
+        } else {
+            if(length(defaultBiocRepos) == 0) {
+                bioc = tryCatch(getBiocReposFromRVers(), function(e) character())
+                if(length(bioc) == 0)
+                    warning("Unable to determine Bioc repositories. They will not be included in the set of default dependency repos")
+            } else
+                bioc = defaultBiocRepos
+        }
+        if(is(bioc, "error") || length(bioc) == 0)
+            return(character())
 
-    if (anyNA(bioc))  {
-        warning("Attempt to determine default Bioconductor repos returned one or more NAs. These will be omitted from the set of default repositories.")
-        bioc = bioc[!is.na(bioc)]
-    }
+        if (anyNA(bioc))  {
+            warning("Attempt to determine default Bioconductor repos returned one or more NAs. These will be omitted from the set of default repositories.")
+            bioc = bioc[!is.na(bioc)]
+        }
+    })
+    if(trim)
+        bioc = trim_potential_bioc_repos(bioc)
     bioc
 }
 
@@ -279,30 +296,32 @@ getBiocRepos = function() {
 ##' @return A character vector of package repository urls
 ##' @export
 ##' @importFrom utils chooseCRANmirror
-defaultRepos = function() {
-    bioc = getBiocRepos()
-    optrepos = getOption("repos")
-    if(is.na(optrepos["CRAN"]) || optrepos["CRAN"] == "@CRAN@") {
-        ## if bioc has a cranmirror (which it should)
-        if(any(grepl("cran", bioc, ignore.case=TRUE))) 
-            optrepos = optrepos[!grepl("CRAN", names(optrepos))]
-        else {
+    defaultRepos = function() {
+       suppressMessages({
+           bioc = getBiocRepos()
+           optrepos = get_repos_option()
+           if(is.na(optrepos["CRAN"]) || optrepos["CRAN"] == "@CRAN@") {
+               ## if bioc has a cranmirror (which it should)
+               if(length(bioc) > 0 && any(grepl("cran", bioc, ignore.case=TRUE)))
+                   optrepos = optrepos[!grepl("CRAN", names(optrepos))]
+               else {
 
-            if(interactive())
-                chooseCRANmirror()
-            else{
-                message("Switchr needs a default CRAN mirror set via R options. Using the cloud mirror. This happens only when no CRAN mirror is selected *and* the BiocInstaller package is not installed.")
-                chooseCRANmirror(ind= 1L)
-            }
-            optrepos = getOption("repos")
-        }
-    } else if (!is.null(names(bioc))) 
-          bioc = bioc[!names(bioc) == "CRAN"]
-    
-    granrepos = NULL
-    if(exists("defaultGRANURL")) 
-        granrepos = get("defaultGRANURL")()
-    repos = unique(c(granrepos, optrepos, bioc))
+                   if(interactive())
+                       chooseCRANmirror()
+                   else{
+                       message("Switchr needs a default CRAN mirror set via R options. Using the cloud mirror. This happens only when no CRAN mirror is selected *and* the BiocInstaller package is not installed.")
+                       chooseCRANmirror(ind= 1L)
+                   }
+                   optrepos = get_repos_option()
+               }
+           } else if (length(bioc) > 0 && !is.null(names(bioc)))
+               bioc = bioc[!names(bioc) == "CRAN"]
+
+           granrepos = NULL
+           if(exists("defaultGRANURL"))
+               granrepos = get("defaultGRANURL")()
+           repos = unique(c(granrepos, optrepos, bioc))
+       })
     repos
 }
 
