@@ -22,7 +22,7 @@ if(switchr:::isWindows())
 ## is specified
 bef = switchrDontUnload()
 af = switchrDontUnload("knitr")
-stopifnot(all(c("stringr", "stringi", "magrittr") %in% af))
+stopifnot(all(tools::package_dependencies("knitr", recursive = TRUE)[[1]] %in% af))
 
 
 ## regression test for unnecessary (and expensive)
@@ -53,8 +53,8 @@ stopifnot(nrow(manifest_df(sman)) == 0 && nrow(versions_df(sman)) == 0)
 ## make sure bioc version stuff works
 isFALSE = function(x) identical(x, FALSE)
 thing = switchr:::develVers
-if(!isFALSE(graceful_inet())) ## absent forced failure bioc urls shoould work...
-    stopifnot(is(thing, "character"))
+## if(!isFALSE(graceful_inet())) ## absent forced failure bioc urls shoould work...
+##     stopifnot(is(thing, "character"))
 
 #stopifnot(nrow(available.packages(contrib.url(switchr:::highestBiocVers())))>0)
 
@@ -90,7 +90,7 @@ dfile = file.path(pkgdir, "DESCRIPTION")
 test_ghupdate_dirty = function() {
     ghsource = makeSource("https://github.com/gmbecker/gRAN", type = "git", scm_auth=list(), branch = "master", name = "GRANBase")
     res = switchr:::inet_handlers(makePkgDir("GRANBase", ghsource, dir, FALSE, param = param))
-    if(is(res, "error")) {
+    if(is(res, "error") || !res) {
         message("skipping github update test due to connectivity issues")
         return(TRUE)
     }
@@ -116,7 +116,7 @@ test_ghupdate_branch = function() {
     ghsourcebr = makeSource("https://github.com/gmbecker/gRAN", type = "git", scm_auth=list(), branch = "API_refactor", name = "GRANBase")
 
     res = switchr:::inet_handlers(makePkgDir("GRANBase", ghsourcebr, dir, FALSE))
-    if(is(res, "error")) {
+    if(is(res, "error") || !res) {
         message("skipping github update test due to connectivity issues")
         return(TRUE)
     }
